Credits
=======

Development Lead
----------------

* Alexander Kavanaugh (@kavdev)
* Daniel Greenfeld <pydanny@gmail.com>

Contributors
------------

* Audrey Roy Greenfeld (@audreyr)
* Buddy Lindsley (@buddylindsey)
* Yasmine Charif (@dollydagr)
* Mahdi Yusuf (@myusuf3)
* Luis Montiel <luismmontielg@gmail.com>
* Kulbir Singh (@kulbir)
* Dustin Farris (@dustinfarris)
* Liwen S (@sunliwen)
* centrove
* Chris Halpert (@cphalpert)
* Thomas Parslow (@almost)
* Leonid Shvechikov (@shvechikov)
* sromero84
* Peter Baumgartner (@ipmb)
* Vikas (@vikasgulati)
* Colton Allen (@cmanallen)
* Filip Wasilewski (@nigma)
* Martin Hill (@martinhill)
* Michael Thornhill <michael.thornhill@gmail.com>
* Tobias Lorenz (@Tyrdall)
* Ben Whalley
* nanvel
* jRobb (@jamesbrobb)
* Areski Belaid (@areski)
* José Padilla (@jpadilla)
* Ben Murden (@benmurden)
* Philippe Luickx (@philippeluickx)
* Chriss Mejía (@chrissmejia)
* Bill Huneke (@wahuneke)
* Matt Shaw (@unformatt)
* Chris Trengove (@ctrengove)
* Caleb Hattingh (@cjrh)
* Nicolas Delaby (@ticosax)
* Michaël Krens (@michi88)
* Yuri Prezument (@yprez)
* Raphael Deem (@r0fls)
* Irfan Ahmad (@erfaan)
* Lee Skillen (@lskillen)
* Slava Kyrachevsky (@scream4ik)
* Alec Brunelle (@aleccool213)
* James Hiew (@jameshiew)
* Dan Koch (@dmkoch)
* Jerome Leclanche (@jleclanche)
